@@ -27,7 +27,7 @@ class ApiRequestManager:
     Class to interact with general api request methods
     """
 
-    def __init__(self, cluster, props):
+    def __init__(self, cluster, props, org_id=None):
         """
         Class constructor
 
@@ -54,6 +54,8 @@ class ApiRequestManager:
         self.pi_tag_export_limit = {"piTagExportLimit": 999}
         self.expiry = {"expiry": 999}
 
+        self.org_id = org_id
+
         auth = self.props.get_auth_token(cluster=self.cluster)
 
         self.api_session_url = self.props.get_remote(cluster=self.cluster) + 'api/sessions'
@@ -78,36 +80,36 @@ class ApiRequestManager:
         """
         self.session.close()
 
-    def verify_auth_token(self):
+    def verify_auth_token(self, cluster_name):
         """
         Verifies if the auth token is set
 
         :return:
         """
-        if self.props.get_auth_token() is None:
+        if self.props.get_auth_token(cluster=cluster_name) is None:
             raise Exception(
                 "Authentication is required with remote server, login running ah login"
             )
 
-    def verify_remote(self):
+    def verify_remote(self, cluster_name):
         """
         Verifies if the remote cluster is set
 
         :return:
         """
-        if self.props.get_remote() is None:
+        if self.props.get_remote(cluster=cluster_name) is None:
             raise Exception(
                 "Remote server must be setup first"
             )
 
-    def verify_properties(self):
+    def verify_properties(self, cluster_name):
         """
         Verify both auth token and remote cluster
 
         :return:
         """
-        self.verify_auth_token()
-        self.verify_remote()
+        self.verify_auth_token(cluster_name=cluster_name)
+        self.verify_remote(cluster_name=cluster_name)
 
     def auth_token(self, query_params={}):
         """
