@@ -24,6 +24,7 @@ from unify.generalutils import json_to_csv
 from unify.properties import Properties
 from unify.properties import ClusterSetting
 from unify.apirequestsmng import ApiRequestManager
+from unify.helpers.SingleOrg import single_org
 
 
 class Pipelines(ApiRequestManager):
@@ -31,7 +32,7 @@ class Pipelines(ApiRequestManager):
     Class to interact with pipeline endpoints
     """
 
-    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING)):
+    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING), org_id=None):
         """
         Class constructor
 
@@ -41,7 +42,7 @@ class Pipelines(ApiRequestManager):
         :type props: class:`unify.properties.Properties`
         """
 
-        super().__init__(cluster=cluster, props=props)
+        super().__init__(cluster=cluster, props=props, org_id=org_id)
 
         try:
 
@@ -93,7 +94,8 @@ class Pipelines(ApiRequestManager):
         except Exception as error:
             raise error
 
-    def apply_map_attributes(self, org_id, pipeline_id, component, payload):
+    @single_org
+    def apply_map_attributes(self, org_id=None, pipeline_id=None, component=None, payload=None):
         """
         Applies map attribute rules to given component
 
@@ -122,7 +124,8 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(result.content))
 
-    def regular_duplicate(self, org_id, pipeline_id, new_name):
+    @single_org
+    def regular_duplicate(self, org_id=None, *, pipeline_id, new_name):
         """
         Will duplicate the given pipeline on the given org
         :param org_id:
@@ -130,6 +133,11 @@ class Pipelines(ApiRequestManager):
         :param new_name:
         :return:
         """
+        if pipeline_id is None:
+            raise Exception("Pipeline id cant be null")
+        if new_name is None:
+            raise Exception("New pipeline name cant be none")
+
         headers = self.build_header(
             org_id=org_id,
             others={"Content-Type": "application/json"}
@@ -153,8 +161,9 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(post_upload_file.content))
 
-
-    def update_pipeline_from_json(self, org_id, update_payload, pipeline_id, pipeline_name, sources=None):
+    @single_org
+    def update_pipeline_from_json(self, org_id=None, update_payload=None, pipeline_id=None, pipeline_name=None,
+                                  sources=None):
         """
         Updates a pipeline with a json content
 
@@ -225,7 +234,8 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(update_pipeline_request.content))
 
-    def download_map_attributes(self, org_id, pipeline_id, component_id):
+    @single_org
+    def download_map_attributes(self, org_id=None, pipeline_id=None, component_id=None):
         """
         Downloads the map attributes data from the given pipeline
 
@@ -255,7 +265,8 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(result.content))
 
-    def upload_map_attributes_from_json(self, org_id, pipeline_id, component_id, json_data):
+    @single_org
+    def upload_map_attributes_from_json(self, org_id=None, pipeline_id=None, component_id=None, json_data=None):
         """
         Uploads a json file to the given map attributes component
 
@@ -280,7 +291,8 @@ class Pipelines(ApiRequestManager):
             csv_file=path
         )
 
-    def upload_map_attributes(self, org_id, pipeline_id, component_id, csv_file):
+    @single_org
+    def upload_map_attributes(self, org_id=None, pipeline_id=None, component_id=None, csv_file=None):
         """
         Uploads a csv file to the given map attributes component
 
@@ -320,7 +332,8 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(post_upload_file.content))
 
-    def create_pipeline(self, name, org_id, function=False):
+    @single_org
+    def create_pipeline(self, name, org_id=None, function=False):
         """
         Creates an empty pipeline
 
@@ -328,6 +341,8 @@ class Pipelines(ApiRequestManager):
         :type name: str
         :param org_id: Org id where the pipeline is going to be created
         :type org_id: int or str
+        :param function: Defines if the pipeline is a function or not
+        :type function: boolean
         :return:
         """
 
@@ -352,6 +367,7 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(json.loads(result.content))
 
+    @single_org
     def download_flow(self, org_id=None, pipeline_id=None, flow_id=None):
         """
         Downloads the flow data
@@ -381,7 +397,8 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(result.content))
 
-    def get_pipeline(self, org_id, pipeline_id):
+    @single_org
+    def get_pipeline(self, org_id=None, *, pipeline_id):
         """
         Retrieves pipeline json blob
 
@@ -405,7 +422,8 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(result.content))
 
-    def get_map_attribute_rules(self, org_id, pipeline_id, component):
+    @single_org
+    def get_map_attribute_rules(self, org_id=None, *, pipeline_id, component):
         """
         Downloads map attributes rules of the given pipeline component
 
@@ -432,7 +450,8 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(result.content))
 
-    def get_distinct_values_map_attributes(self, org_id, pipeline_id, flows, columns):
+    @single_org
+    def get_distinct_values_map_attributes(self, org_id=None, *, pipeline_id, flows, columns):
         """
         Retrieves distinct values from the given flow id
 
@@ -470,6 +489,7 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(result.content))
 
+    @single_org
     def get_pipelines_v2(self, org_id=None):
         """
         Retrieves the pipeline list from the given org
@@ -492,7 +512,8 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(get_pipelines_request.content))
 
-    def verify_if_pipeline_exists_and_get_id(self, org_id, pipeline_name):
+    @single_org
+    def verify_if_pipeline_exists_and_get_id(self, org_id=None, *, pipeline_name):
         """
         Verifies that the pipeline name exists on the given org. Returns pipeline id.
 
@@ -502,6 +523,10 @@ class Pipelines(ApiRequestManager):
         :type pipeline_name: str
         :return:
         """
+
+        if pipeline_name is None:
+            raise Exception("New pipeline name cant be none")
+
         pipeline_list = self.get_pipelines_v2(org_id=org_id)
 
         results = {"pipeline_id": None}
@@ -514,7 +539,8 @@ class Pipelines(ApiRequestManager):
 
         return results
 
-    def pipeline_exists(self, org_id, pipeline_name):
+    @single_org
+    def pipeline_exists(self, org_id=None, *, pipeline_name):
         """
         Verifies that the pipeline name exists on the given org
 
@@ -524,6 +550,9 @@ class Pipelines(ApiRequestManager):
         :type pipeline_name: str
         :return:
         """
+        if pipeline_name is None:
+            raise Exception("New pipeline name cant be none")
+
         return self.verify_if_pipeline_exists_and_get_id(
             org_id=org_id,
             pipeline_name=pipeline_name
