@@ -28,6 +28,7 @@ from .generalutils import json_to_csv
 from .generalutils import create_schema_dataset
 from .generalutils import stream_iterable
 from .WaitingLibrary import Wait
+from unify.helpers.SingleOrg import single_org
 
 
 class Sources(ApiRequestManager):
@@ -35,7 +36,7 @@ class Sources(ApiRequestManager):
     Class to interact with dataset endpoints
     """
 
-    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING)):
+    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING), org_id=None):
         """
         Class constructor
 
@@ -45,7 +46,7 @@ class Sources(ApiRequestManager):
         :type props: class:`unify.properties.Properties`
         """
 
-        super().__init__(cluster=cluster, props=props)
+        super().__init__(cluster=cluster, props=props, org_id=org_id)
 
         try:
 
@@ -214,8 +215,9 @@ class Sources(ApiRequestManager):
 
         return dataset_data
 
+    @single_org
     def upload_big_dataset(
-            self, name, org_id, content, format="csv",
+            self, name, org_id=None, *, content, format="csv",
             convert_to_parquet="false", encoding='UTF-8', chunks=10000):
         """
         Upload a dataset through the static route. This method should be used when
@@ -310,9 +312,18 @@ class Sources(ApiRequestManager):
 
         return dataset_data
 
+    @single_org
     def create_api_data_set(
-            self, name, org_id, file_path, format="csv",
-            convert_to_parquet="false", encoding="UTF-8"):
+            self,
+            name,
+            org_id=None,
+            *,
+            file_path,
+            format="csv",
+            convert_to_parquet="false",
+            encoding="UTF-8"
+    ):
+
         """
         Creates a dataset through the static file route.
 
@@ -331,21 +342,26 @@ class Sources(ApiRequestManager):
         :return:
         """
 
+        if file_path is None:
+            raise Exception("File Path must not be None")
+
         content = open(file_path, "r+").read()
 
         return self.create_api_data_set_with_content(
-            name,
-            org_id,
-            content,
-            format,
-            convert_to_parquet,
-            encoding
+            name=name,
+            org_id=org_id,
+            content=content,
+            format=format,
+            convert_to_parquet=convert_to_parquet,
+            encoding=encoding
         )
 
+    @single_org
     def create_api_data_set_with_content(
             self,
             name,
-            org_id,
+            org_id=None,
+            *,
             content,
             format="csv",
             convert_to_parquet="false",
@@ -403,7 +419,8 @@ class Sources(ApiRequestManager):
 
         return results
 
-    def get_commit_status(self, org_id, data_set_id, commit_id):
+    @single_org
+    def get_commit_status(self, org_id=None, *, data_set_id, commit_id):
         """
         Retrieves the status of the given commit id.
 
@@ -426,7 +443,8 @@ class Sources(ApiRequestManager):
 
         return json.loads(test_request.content.decode('utf8')), test_request.status_code
 
-    def download_dataset_content(self, org_id, dataset_id):
+    @single_org
+    def download_dataset_content(self, org_id=None, *, dataset_id):
         """
         Downloads the content of a given dataset.
 
@@ -450,7 +468,8 @@ class Sources(ApiRequestManager):
 
         raise Exception(repr(get_source_request.content))
 
-    def create_export_dataset(self, org_id, dataset_ids):
+    @single_org
+    def create_export_dataset(self, org_id=None, *, dataset_ids):
         """
         Create the content needed to export a dataset.
         This is usually used when using the import dataset.
@@ -496,9 +515,10 @@ class Sources(ApiRequestManager):
 
         return json.dumps(all_datasets)
 
+    @single_org
     def add_data_to_existing_source(
-            self, name, org_id, file_path,
-            data_set_id, group_id, format="csv"):
+            self, name, org_id=None, *, file_path,
+            data_set_id, group_id=None, format="csv"):
         """
         Helper function to append data to existing dataset
 
@@ -539,8 +559,9 @@ class Sources(ApiRequestManager):
 
         return results
 
+    @single_org
     def overwrite_dataset(
-            self, org_id, data_set_id, file_path, group_id=None,
+            self, org_id=None, *, data_set_id, file_path, group_id=None,
             format="csv", convert_to_parquet="false"):
 
         """
@@ -614,7 +635,8 @@ class Sources(ApiRequestManager):
         else:
             raise Exception(repr(request.content))
 
-    def truncate_data_set(self, org_id, data_set_id):
+    @single_org
+    def truncate_data_set(self, org_id=None, *, data_set_id):
         """
         Truncates the dataset content.
 
@@ -627,7 +649,8 @@ class Sources(ApiRequestManager):
         command = {"commands": [{"$type": "truncate", "cause": []}]}
         return self._commit_dataset_command(org_id, data_set_id, command)
 
-    def append_dataset(self, org_id, data_set_id, content):
+    @single_org
+    def append_dataset(self, org_id=None, *, data_set_id, content):
         """
         Appends data to existing dataset.
 
@@ -941,7 +964,8 @@ class Sources(ApiRequestManager):
 
         raise Exception(repr(post_upload_pitag.content))
 
-    def static_file_upload(self, name, content, org_id):
+    @single_org
+    def static_file_upload(self, name, content, org_id=None):
         """
         Uploads a static file with content.
 
@@ -976,7 +1000,8 @@ class Sources(ApiRequestManager):
 
         raise Exception(repr(post_upload_file.content))
 
-    def get_sources(self, org_id):
+    @single_org
+    def get_sources(self, org_id=None):
         """
         Retrieves all the metadata of datasets on an org.
 
@@ -994,7 +1019,7 @@ class Sources(ApiRequestManager):
 
             query_strings = {
                 "ean.orgs": org_id,
-                "_fields": "schema,ean.ready,ean.source_type"
+                "_fields": "schema,ean.ready,ean.source_type,ean.facets,ean.table,ean.description,ean.dataArchiveServerName"
             }
 
             get_sources_request = self.session.get(
@@ -1048,10 +1073,11 @@ class Sources(ApiRequestManager):
 
         raise Exception(repr(get_sources_request.content))
 
-    def delete_source(self, org_id, source_id):
-
+    @single_org
+    def delete_source(self, org_id=None, *, source_id):
         """
         This method deletes a dataset that is stored on the org_id with the given source_id
+
         :param org_id: Organization ID where the datasets is stored
         :type org_id: int or str
         :param source_id: Data set id to be deleted
